BlocState class

Constructors

BlocState({bool? equatable, bool? copyWith, bool? isBuilder, bool? isListener})
const

Properties

copyWith bool?
final
equatable bool?
final
hashCode int
The hash code for this object.
no setterinherited
isBuilder bool?
final
isListener bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited