BlocStates class

Constructors

BlocStates({bool? copyWith, bool? stateWhen, bool? buildWhen, bool? listenWhen, bool? equatable})
const

Properties

buildWhen bool?
final
copyWith bool?
final
equatable bool?
final
hashCode int
The hash code for this object.
no setterinherited
listenWhen bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateWhen bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited